@@ -1,7 +1,14 @@
-class ValidationException(Exception): pass
+from functools import wraps
 
 def required_attrs(attrs):
+    """decorator for marking a list of attributes required before calling a function
+
+    :param attrs: List of attributes that must be set
+    :type attrs: list.
+    :raises: `ValidationException`
+    """
     def wrapper(method):
+        @wraps(method)
         def validate(obj, *args, **kwargs):
             for ra in attrs:
                 try:
@@ -13,3 +20,4 @@ def required_attrs(attrs):
         return validate
     return wrapper
 
+class ValidationException(Exception): pass
\ No newline at end of file
