@@ -73,6 +73,7 @@ class Resource(object):
         self.__last_request = None
         self.__last_error = None
         self.__current_job = None
+        self.__payload_format = 'json'
         self.__request_details = request_details
         self.pending_changes = {}
 
@@ -107,6 +108,15 @@ class Resource(object):
     def request_details(self, level):
         self.__request_details = level
 
+    @property
+    def payload_format(self):
+        """The format of the payload: `json` or `xml`"""
+        return self.__payload_format
+
+    @payload_format.setter
+    def payload_format(self, p_format):
+        self.__payload_format = p_format
+
     @property
     def path(self):
         """The path used in the API request (e.g. ``admin/Job``)"""
@@ -186,19 +196,30 @@ class Resource(object):
         failures = [400, 403, 404, 409, 500, 501, 503]
         sig = auth.get_sig(method, self.path)
         url = settings.endpoint+'/'+self.path
+        ssl_verify = settings.ssl_verify
+
+        if self.payload_format == 'xml':
+            payload_format = 'application/xml'
+        elif self.payload_format == 'json':
+            payload_format = 'application/json'
+        else:
+            raise AttributeError('Wrong payload format: %s' % self.payload_format)
 
         headers = {'x-esauth-access': sig['access_key'],
         'x-esauth-timestamp': str(sig['timestamp']),
         'x-esauth-signature': str(sig['signature']),
         'x-es-details': self.request_details,
-        'Accept': 'application/json',
+        'Accept': payload_format,
         'User-Agent': sig['ua']}
 
-        #results = getattr(r, method.lower())(url, headers=headers, *args, **kwargs)
-        results = r.request(method, url, headers=headers, **kwargs)
+        results = r.request(method, url, headers=headers, verify=ssl_verify, **kwargs)
 
         self.last_error = None
         self.last_request = results
+
+        if self.payload_format == 'xml':
+            return results
+
         if results.status_code in failures:
             try:
                 err = results.json()
